==> Ecdat_0.1-3.tar.gz: Ecdat/man/Housing.Rd <==
\name{Housing}
\docType{data}
\alias{Housing}
\title{Sales Prices of Houses in the City of Windsor }
\description{
  a cross-section from 1987

 \emph{number of observations} :  546

   \emph{country} :  Canada

}
\usage{data(Housing)}
\format{A dataframe containing :
  \describe{
    \item{price}{sale price of a house}
    \item{lotsize}{the lot size of a property in square feet}
    \item{bedrooms}{number of bedrooms}
    \item{bathrms}{number of full bathrooms}
    \item{stories}{number of stories excluding basement}
    \item{driveway}{does the house has a driveway ?  a factor }
    \item{recroom}{does the house has a recreational room ? a factor}
    \item{fullbase}{does the house has a full finished basement ? a factor}
    \item{gashw}{does the house uses gas for hot water heating ? a factor }
    \item{airco}{does the house has central air conditioning ? a factor }
    \item{garagepl}{number of garage places}
    \item{prefarea}{is the house located in the preferred neighbourhood of the city ? a factor}
  }
}
\source{
    Anglin, P.M.  and  R.  Gencay (1996) \dQuote{Semiparametric estimation of a hedonic price function}, \emph{Journal of Applied Econometrics }, \bold{11(6)}, 633-648.

}
\references{
    Verbeek, Marno (2004) \emph{A guide to modern econometrics}, John Wiley and Sons, \url{http://www.econ.kuleuven.ac.be/GME}.
}
\seealso{\code{\link{Index.Books}}, \code{\link{Index.Economics}}, \code{\link{Index.Econometrics}}, \code{\link{Index.Observations}}}

\keyword{datasets}

==> Ecdat_0.1-4.tar.gz: Ecdat/man/Housing.Rd <==
\name{Housing}
\docType{data}
\alias{Housing}
\title{Sales Prices of Houses in the City of Windsor }
\description{
  a cross-section from 1987

 \emph{number of observations} :  546

   \emph{country} :  Canada

}
\usage{data(Housing)}
\format{A dataframe containing :
  \describe{
    \item{price}{sale price of a house}
    \item{lotsize}{the lot size of a property in square feet}
    \item{bedrooms}{number of bedrooms}
    \item{bathrms}{number of full bathrooms}
    \item{stories}{number of stories excluding basement}
    \item{driveway}{does the house has a driveway ?  a factor }
    \item{recroom}{does the house has a recreational room ? a factor}
    \item{fullbase}{does the house has a full finished basement ? a factor}
    \item{gashw}{does the house uses gas for hot water heating ? a factor }
    \item{airco}{does the house has central air conditioning ? a factor }
    \item{garagepl}{number of garage places}
    \item{prefarea}{is the house located in the preferred neighbourhood of the city ? a factor}
  }
}
\source{
    Anglin, P.M.  and  R.  Gencay (1996) \dQuote{Semiparametric estimation of a hedonic price function}, \emph{Journal of Applied Econometrics }, \bold{11(6)}, 633-648.

}
\references{
    Verbeek, Marno (2004) \emph{A guide to modern econometrics}, John Wiley and Sons, \url{http://www.econ.kuleuven.ac.be/GME}, chapter 3.

}
\seealso{\code{\link{Index.Books}}, \code{\link{Index.Economics}}, \code{\link{Index.Econometrics}}, \code{\link{Index.Observations}}}

\keyword{datasets}
